HueSDK.API.Schedules (HueSDK v0.1.0) View Source
Interface to the Schedules API
See the official documentation for more information.
Link to this section Summary
Functions
Allows the user to create new schedules. The bridge can store up to 100 schedules.
Deletes a schedule from the bridge.
Gets a list of all schedules that have been added to the bridge.
Gets all attributes for a schedule.
Allows the user to change attributes of a schedule.
Link to this section Functions
Specs
create_schedule(HueSDK.Bridge.t(), map()) :: HueSDK.HTTP.response()
Allows the user to create new schedules. The bridge can store up to 100 schedules.
Specs
delete_schedule(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()
Deletes a schedule from the bridge.
Specs
get_all_schedules(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()
Gets a list of all schedules that have been added to the bridge.
Specs
get_schedule_attributes(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()
Gets all attributes for a schedule.
Specs
set_schedule_attributes(HueSDK.Bridge.t(), String.t(), map()) :: HueSDK.HTTP.response()
Allows the user to change attributes of a schedule.