HueSDK.API.Sensors (HueSDK v0.1.0) View Source

Interface to the Sensors API.

See the official documentation for more information.

Link to this section Summary

Functions

Allows the creation of sensors.

All sensors can be deleted.

Gets a list of all sensors that have been added to the bridge.

Finds all new sensors since the last scan.

Gets the sensor from the bridge with the given id.

Starts a search for new sensors.

The allowed configuration parameters depend on the sensor type.

Renames the sensor in the bridge for the supplied id.

Used to allow the state of a CLIP sensor to be updated.

Link to this section Functions

Link to this function

create_sensor(bridge, attributes)

Specs

create_sensor(HueSDK.Bridge.t(), map()) :: HueSDK.HTTP.response()

Allows the creation of sensors.

Link to this function

delete_sensor(bridge, sensor_id)

Specs

delete_sensor(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()

All sensors can be deleted.

Specs

get_all_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()

Gets a list of all sensors that have been added to the bridge.

Specs

get_new_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()

Finds all new sensors since the last scan.

Link to this function

get_sensor_attributes(bridge, sensor_id)

Specs

get_sensor_attributes(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()

Gets the sensor from the bridge with the given id.

Link to this function

search_for_new_sensors(bridge)

Specs

search_for_new_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()

Starts a search for new sensors.

Link to this function

set_sensor_attributes(bridge, sensor_id, attributes)

Specs

set_sensor_attributes(HueSDK.Bridge.t(), String.t(), map()) ::
  HueSDK.HTTP.response()

The allowed configuration parameters depend on the sensor type.

Link to this function

set_sensor_name(bridge, sensor_id, name)

Specs

set_sensor_name(HueSDK.Bridge.t(), String.t(), String.t()) ::
  HueSDK.HTTP.response()

Renames the sensor in the bridge for the supplied id.

Link to this function

set_sensor_state(bridge, sensor_id, state)

Specs

set_sensor_state(HueSDK.Bridge.t(), String.t(), map()) :: HueSDK.HTTP.response()

Used to allow the state of a CLIP sensor to be updated.