HueSDK.API.Sensors (HueSDK v0.1.0) View Source
Interface to the Sensors API.
See the official documentation for more information.
Link to this section Summary
Functions
Allows the creation of sensors.
All sensors can be deleted.
Gets a list of all sensors that have been added to the bridge.
Finds all new sensors since the last scan.
Gets the sensor from the bridge with the given id.
Starts a search for new sensors.
The allowed configuration parameters depend on the sensor type.
Renames the sensor in the bridge for the supplied id.
Used to allow the state of a CLIP sensor to be updated.
Link to this section Functions
Specs
create_sensor(HueSDK.Bridge.t(), map()) :: HueSDK.HTTP.response()
Allows the creation of sensors.
Specs
delete_sensor(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()
All sensors can be deleted.
Specs
get_all_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()
Gets a list of all sensors that have been added to the bridge.
Specs
get_new_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()
Finds all new sensors since the last scan.
Specs
get_sensor_attributes(HueSDK.Bridge.t(), String.t()) :: HueSDK.HTTP.response()
Gets the sensor from the bridge with the given id.
Specs
search_for_new_sensors(HueSDK.Bridge.t()) :: HueSDK.HTTP.response()
Starts a search for new sensors.
Specs
set_sensor_attributes(HueSDK.Bridge.t(), String.t(), map()) :: HueSDK.HTTP.response()
The allowed configuration parameters depend on the sensor type.
Specs
set_sensor_name(HueSDK.Bridge.t(), String.t(), String.t()) :: HueSDK.HTTP.response()
Renames the sensor in the bridge for the supplied id.
Specs
set_sensor_state(HueSDK.Bridge.t(), String.t(), map()) :: HueSDK.HTTP.response()
Used to allow the state of a CLIP sensor to be updated.