HueSDK.Config (HueSDK v0.1.0) View Source
Application configuration available for HueSDK.
Link to this section Summary
Functions
The DNS host of the Hue Bridge discovery portal. Defaults to discovery.meethue.com.
Should SSL be used for requests made to the Hue Bridge? Defaults to true.
Link to this section Functions
Specs
portal_host() :: String.t()
The DNS host of the Hue Bridge discovery portal. Defaults to discovery.meethue.com.
Examples
Configuring a custom host for HueSDK.Discovery.NUPNP requests:
config :hue_sdk, portal_host: "discovery.meethue.com"
Specs
ssl?() :: boolean()
Should SSL be used for requests made to the Hue Bridge? Defaults to true.
Hue Bridge SSL certificates are self-signed. The first certificate received will be pinned and used to verify subsequent responses.
Examples
Enabling SSL for all requests made to the Hue Bridge:
config :hue_sdk, ssl: trueDisabling SSL for all requests made to the Hue Bridge:
config :hue_sdk, ssl: false